#-----------------------------------------------------------
#	TweetFix.py
#	By NightWork
#
#-----------------------------------------------------------
#	送信されたメッセージからTwitterのURLを抽出、
#	展開サービスのURLに書き換えてリプライを送信するDiscord用bot
#
#-----------------------------------------------------------

#===========================================================
# 各種設定
#===========================================================
#インポート
import configparser
import discord
import re


#設定ファイル読込
config = configparser.ConfigParser()
config.read('TweetFix.ini')


#DiscordBOTトークン
TOKEN = config['Config']['TOKEN']


#URL正規表現
RE_TEXT_TWITTER	= 'https:\/\/twitter\.com\/[0-9a-zA-Z_]{0,15}\/status\/[0-9]+'
RE_TEXT_X	= 'https:\/\/x\.com\/[0-9a-zA-Z_]{0,15}\/status\/[0-9]+'
RE_TEXT		= RE_TEXT_TWITTER + '|' + RE_TEXT_X


#置換文字列
SEARCHTEXT_TWITTER	= 'https://twitter.com'
SEARCHTEXT_X		= 'https://x.com'
REPLACETEXT		= 'https://vxtwitter.com'


#起動オプション
intents=discord.Intents.default()
intents.message_content = True
client = discord.Client(intents=intents)



#===========================================================
# イベントハンドラ
#===========================================================
#-----------------------------------------------------------
# 起動
#-----------------------------------------------------------
@client.event
async def on_ready():
 print('ログインに成功しました。')
 await client.change_presence(activity=discord.Game(name="Tweetを展開中"))



#-----------------------------------------------------------
# メッセージ受信
#-----------------------------------------------------------
@client.event
async def on_message(message):
 # botからのメッセージは処理させない
 if message.author.bot:
  return

 #メッセージ情報
 msg_txt = message.content

 #ツイートが含まれるか検索
 if re.search(RE_TEXT , msg_txt):
  print('\n==================================================')
  print('メッセージ')
  print(msg_txt)


  #すべてのURLを取得し改行区切りで結合
  url_list = "\n".join(re.findall(RE_TEXT, msg_txt))

  #抽出結果
  print('\n--------------------------------------------------')
  print('抽出結果')
  print(url_list)


  #URL修正
  url_list_fix = url_list.replace(SEARCHTEXT_TWITTER, REPLACETEXT)
  url_list_fix = url_list_fix.replace(SEARCHTEXT_X, REPLACETEXT)
  print('--------------------------------------------------')
  print('修正後URL一覧')
  print(url_list_fix)


  #メッセージ送信
  await message.reply(url_list_fix, mention_author=False)



#-----------------------------------------------------------
# bot起動
#-----------------------------------------------------------
client.run(TOKEN)
